@@ -27,7 +27,7 @@ def push_software(fpath, radarType, version_name):
 
     # check if can open file path
     if os.path.isfile(fpath):
-        logger.log(message="ZIP file exists: " + fpath, log_level="info", to_file=True, to_terminal=True)
+        logger.log(message="ZIP file exists (PS): " + fpath, log_level="info", to_file=True, to_terminal=True)
         # print("ZIP file exists: " + fpath)
     else:
         logger.log(message="ZIP not exist (PS): " + fpath, log_level="error", to_file=True, to_terminal=True)
